## Helix operations

::: pybes3.tracks.helix.HelixObject
---
::: pybes3.tracks.helix.helix_obj
---
::: pybes3.tracks.helix.dr_phi0_to_x
---
::: pybes3.tracks.helix.dr_phi0_to_y
---
::: pybes3.tracks.helix.phi0_to_phi
---
::: pybes3.tracks.helix.kappa_to_pt
---
::: pybes3.tracks.helix.kappa_to_charge
---
::: pybes3.tracks.helix.kappa_to_radius
---
::: pybes3.tracks.helix.HelixAwkwardRecord
---
::: pybes3.tracks.helix.HelixAwkwardArray
---
::: pybes3.tracks.helix.helix_awk
---

### Old helix

!!! warning "Deprecated"
    This component is deprecated and will be removed in the future. Please use the new `pybes3.tracks.helix` module instead.

::: pybes3.tracks.old_helix.parse_helix
---
::: pybes3.tracks.old_helix._helix01_to_x
---
::: pybes3.tracks.old_helix._helix01_to_y
---
::: pybes3.tracks.old_helix._helix2_to_pt
---
::: pybes3.tracks.old_helix._helix2_to_charge
---
::: pybes3.tracks.old_helix._pt_helix1_to_px
---
::: pybes3.tracks.old_helix._pt_helix1_to_py
---
::: pybes3.tracks.old_helix._pt_helix4_to_p
---
